==> lifestyle-sylius-rest-client-bundle-2.5.0-721843.zip: src/Services/ProductVariant/Version1/Update/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update;

use Lifestyle\DataCollector\DataCollectorInterface;
use Lifestyle\Sylius\RestApiClientBundle\ApiConfiguration\ProductVariantServiceConfiguration;
use Lifestyle\Sylius\RestApiClientBundle\Exception\InvalidConfigurationException;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Response\ProductOption as ProductOptionResponse;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ChannelPrice;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ProductVariantInterface;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update
 */
class Mapper
{
    /**
     * @var ProductVariantServiceConfiguration
     */
    private $configuration;

    /**
     * @var string
     */
    private $modelClass;

    /**
     * Mapper constructor.
     * @param ProductVariantServiceConfiguration $configuration
     */
    public function __construct(ProductVariantServiceConfiguration $configuration)
    {
        $this->configuration = $configuration;
    }

    /**
     * @param string $modelClass
     */
    public function setModelClass(string $modelClass)
    {
        $this->modelClass = $modelClass;
    }

    /**
     * @param DataCollectorInterface $collector
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $product = $this->createModel();
        $product->setCode($collector->getItemValue('id'));
        $product->setOnHand($collector->getItemValue('onHand'));
        $product->setTracked($collector->getItemValue('tracked'));
        $product->setTaxCategory($collector->getItemValue('taxCategory'));
        $product->setHeight($collector->getItemValue('height'));
        $product->setWidth($collector->getItemValue('width'));
        $product->setDepth($collector->getItemValue('depth'));
        $product->setWeight($collector->getItemValue('weight'));
        $product->setVersion($collector->getItemValue('version'));

        if ($this->configuration->isEnableSku()) {
            if ($collector->hasItem('sku')) {
                $product->setSku($collector->getItemValue('sku'));
            } else {
                // Fallback for BC
                $product->setSku($collector->getItemValue('articleNumber'));
            }
        }

        if ($this->configuration->isEnableShippingCategory()) {
            $product->setShippingCategory($collector->getItemValue('shippingCategory'));
            $product->setShippingRequired((bool)$collector->getItemValue('shippingRequired'));
        }

        if ($collector->hasItem('enabled')) {
            $product->setEnabled((bool)$collector->getItemValue('enabled'));
        }

        $product = $this->mapChannelPrices($collector, $product);
        $product = $this->mapLocalizedFields($collector, $product);
        return $this->mapOptions($collector, $product);
    }

    /**
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    private function createModel(): ProductVariantInterface
    {
        $model = new $this->modelClass;

        if (!$model instanceof ProductVariantInterface) {
            throw new InvalidConfigurationException(
                sprintf(
                    'Request model class for updating product variants must implement %s. %s given.',
                    ProductVariantInterface::class,
                    $this->modelClass
                )
            );
        }

        return $model;
    }

    /**
     * @param DataCollectorInterface $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapOptions(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        if ($collector->hasItem('options')) {
            $options = $collector->getItemValue('options');
            foreach ((is_array($options) ? $options : [$options]) as $optionCode) {
                $optionValues = [];
                if ($collector->hasItem('options_' . $optionCode)) {
                    $optionValues = $collector->getItemValue('options_' . $optionCode);
                }
                foreach ((is_array($optionValues) ? $optionValues : [$optionValues]) as $optionValue) {
                    if (0 < strlen($optionValue)) {
                        $product->addOptionValue($optionCode, ProductOptionResponse::buildCode($optionCode, (string)$optionValue));
                    }
                }
            }
        }

        return $product;
    }

    /**
     * @param DataCollectorInterface $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapLocalizedFields(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $productName = (string)($collector->getItemValue('name', $locale) ?: $collector->getItemValue('id'));
            $translation = new Translation();
            $translation->setLocale($locale);
            $translation->setName($productName);
            $product->addTranslation($translation);
        }

        return $product;
    }

    /**
     * @param DataCollectorInterface $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapChannelPrices(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        if ($collector->hasItem('channelPrices')) {
            foreach ($collector->getItemValue('channelPrices') as $channelCode => $channelPrice) {
                $channelPriceItem = new ChannelPrice();
                $channelPriceItem->setChannel($channelCode);
                $channelPriceItem->setPrice($channelPrice['price']);
                $channelPriceItem->setOriginalPrice($channelPrice['originalPrice']);
                $product->addChannelPricing($channelPriceItem);
            }
        }

        return $product;
    }
}

==> lifestyle-sylius-rest-client-bundle-2.6.1-263bb7.zip: src/Services/ProductVariant/Version1/Update/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

declare(strict_types=1);

namespace Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update;

use Lifestyle\DataCollector\DataCollectorInterface;
use Lifestyle\Sylius\RestApiClientBundle\ApiConfiguration\ProductVariantServiceConfiguration;
use Lifestyle\Sylius\RestApiClientBundle\Exception\InvalidConfigurationException;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductOption\Version1\GeneralModels\Response\ProductOption as ProductOptionResponse;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Model\Request\BulkPrice;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ChannelPrice;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\ProductVariantInterface;
use Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update\Model\Request\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Sylius\RestApiClientBundle\Services\ProductVariant\Version1\Update
 */
class Mapper
{
    /**
     * @var ProductVariantServiceConfiguration
     */
    private $configuration;

    /**
     * @var string
     */
    private $modelClass;

    /**
     * Mapper constructor.
     * @param ProductVariantServiceConfiguration $configuration
     */
    public function __construct(ProductVariantServiceConfiguration $configuration)
    {
        $this->configuration = $configuration;
    }

    /**
     * @param string $modelClass
     */
    public function setModelClass(string $modelClass)
    {
        $this->modelClass = $modelClass;
    }

    /**
     * @param DataCollectorInterface $collector
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $product = $this->createModel();
        $product->setCode($collector->getItemValue('id'));
        $product->setOnHand($collector->getItemValue('onHand'));
        $product->setTracked($collector->getItemValue('tracked'));
        $product->setTaxCategory($collector->getItemValue('taxCategory'));
        $product->setHeight($collector->getItemValue('height'));
        $product->setWidth($collector->getItemValue('width'));
        $product->setDepth($collector->getItemValue('depth'));
        $product->setWeight($collector->getItemValue('weight'));
        $product->setVersion($collector->getItemValue('version'));

        if ($this->configuration->isEnableSku()) {
            if ($collector->hasItem('sku')) {
                $product->setSku($collector->getItemValue('sku'));
            } else {
                // Fallback for BC
                $product->setSku($collector->getItemValue('articleNumber'));
            }
        }

        if ($this->configuration->isEnableShippingCategory()) {
            $product->setShippingCategory($collector->getItemValue('shippingCategory'));
            $product->setShippingRequired((bool) $collector->getItemValue('shippingRequired'));
        }

        if ($collector->hasItem('enabled')) {
            $product->setEnabled((bool) $collector->getItemValue('enabled'));
        }

        if ($collector->hasItem('availabilityIndicator')) {
            $product->setAvailabilityIndicator($collector->getItemValue('availabilityIndicator'));
        }

        if ($collector->hasItem('concept')) {
            $product->setConcept($collector->getItemValue('concept'));
        }

        $product = $this->mapChannelPrices($collector, $product);
        $product = $this->mapBulkPrices($collector, $product);
        $product = $this->mapLocalizedFields($collector, $product);

        return $this->mapOptions($collector, $product);
    }

    /**
     * @return ProductVariantInterface
     * @throws InvalidConfigurationException
     */
    private function createModel(): ProductVariantInterface
    {
        $model = new $this->modelClass();

        if (!$model instanceof ProductVariantInterface) {
            throw new InvalidConfigurationException(
                sprintf(
                    'Request model class for updating product variants must implement %s. %s given.',
                    ProductVariantInterface::class,
                    $this->modelClass
                )
            );
        }

        return $model;
    }

    /**
     * @param DataCollectorInterface  $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapOptions(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        if ($collector->hasItem('options')) {
            $options = $collector->getItemValue('options');
            foreach ((is_array($options) ? $options : [$options]) as $optionCode) {
                $optionValues = [];
                if ($collector->hasItem('options_' . $optionCode)) {
                    $optionValues = $collector->getItemValue('options_' . $optionCode);
                }
                foreach ((is_array($optionValues) ? $optionValues : [$optionValues]) as $optionValue) {
                    if (0 < strlen($optionValue)) {
                        $product->addOptionValue(
                            $optionCode,
                            ProductOptionResponse::buildCode(
                                $optionCode,
                                (string) $optionValue
                            )
                        );
                    }
                }
            }
        }

        return $product;
    }

    /**
     * @param DataCollectorInterface  $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapLocalizedFields(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $productName = (string) ($collector->getItemValue('name', $locale) ?: $collector->getItemValue('id'));
            $translation = new Translation();
            $translation->setLocale($locale);
            $translation->setName($productName);
            $product->addTranslation($translation);
        }

        return $product;
    }

    /**
     * @param DataCollectorInterface  $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapChannelPrices(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        if ($collector->hasItem('channelPrices')) {
            foreach ($collector->getItemValue('channelPrices') as $channelCode => $channelPrice) {
                $channelPriceItem = new ChannelPrice();
                $channelPriceItem->setChannel($channelCode);
                $channelPriceItem->setPrice($channelPrice['price']);
                $channelPriceItem->setOriginalPrice($channelPrice['originalPrice']);
                $product->addChannelPricing($channelPriceItem);
            }
        }

        return $product;
    }

    /**
     * @param DataCollectorInterface  $collector
     * @param ProductVariantInterface $product
     * @return ProductVariantInterface
     */
    private function mapBulkPrices(
        DataCollectorInterface $collector,
        ProductVariantInterface $product
    ): ProductVariantInterface {
        if ($collector->hasItem('bulkPrices')) {
            foreach ($collector->getItemValue('bulkPrices') as $bulkPrice) {
                $bulkPriceObject = new BulkPrice();
                $bulkPriceObject->setChannel($bulkPrice['channel']);
                $bulkPriceObject->setPrice($bulkPrice['price']);
                $bulkPriceObject->setQuantity($bulkPrice['quantity']);
                $bulkPriceObject->setList($bulkPrice['list']);
                $product->addBulkPrices($bulkPriceObject);
            }
        }

        return $product;
    }
}
